/****************************************************************************
** Meta object code from reading C++ file 'providermanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../attica-6.26.0/src/providermanager.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'providermanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Attica15ProviderManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Attica::ProviderManager::qt_create_metaobjectdata<qt_meta_tag_ZN6Attica15ProviderManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Attica::ProviderManager",
        "providerAdded",
        "",
        "Attica::Provider",
        "provider",
        "defaultProvidersLoaded",
        "authenticationCredentialsMissing",
        "Provider",
        "failedToLoad",
        "QUrl",
        "QNetworkReply::NetworkError",
        "error",
        "fileFinished",
        "url",
        "authenticate",
        "QNetworkReply*",
        "QAuthenticator*",
        "proxyAuthenticationRequired",
        "QNetworkProxy",
        "proxy",
        "authenticator",
        "slotLoadDefaultProvidersInternal"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'providerAdded'
        QtMocHelpers::SignalData<void(const Attica::Provider &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'defaultProvidersLoaded'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authenticationCredentialsMissing'
        QtMocHelpers::SignalData<void(const Provider &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 4 },
        }}),
        // Signal 'failedToLoad'
        QtMocHelpers::SignalData<void(const QUrl &, QNetworkReply::NetworkError)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 4 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'fileFinished'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'authenticate'
        QtMocHelpers::SlotData<void(QNetworkReply *, QAuthenticator *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 2 }, { 0x80000000 | 16, 2 },
        }}),
        // Slot 'proxyAuthenticationRequired'
        QtMocHelpers::SlotData<void(const QNetworkProxy &, QAuthenticator *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 16, 20 },
        }}),
        // Slot 'slotLoadDefaultProvidersInternal'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProviderManager, qt_meta_tag_ZN6Attica15ProviderManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Attica::ProviderManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Attica15ProviderManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Attica15ProviderManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Attica15ProviderManagerE_t>.metaTypes,
    nullptr
} };

void Attica::ProviderManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProviderManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->providerAdded((*reinterpret_cast<std::add_pointer_t<Attica::Provider>>(_a[1]))); break;
        case 1: _t->defaultProvidersLoaded(); break;
        case 2: _t->authenticationCredentialsMissing((*reinterpret_cast<std::add_pointer_t<Provider>>(_a[1]))); break;
        case 3: _t->failedToLoad((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2]))); break;
        case 4: _t->fileFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->authenticate((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAuthenticator*>>(_a[2]))); break;
        case 6: _t->proxyAuthenticationRequired((*reinterpret_cast<std::add_pointer_t<QNetworkProxy>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAuthenticator*>>(_a[2]))); break;
        case 7: _t->slotLoadDefaultProvidersInternal(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProviderManager::*)(const Attica::Provider & )>(_a, &ProviderManager::providerAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProviderManager::*)()>(_a, &ProviderManager::defaultProvidersLoaded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProviderManager::*)(const Provider & )>(_a, &ProviderManager::authenticationCredentialsMissing, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProviderManager::*)(const QUrl & , QNetworkReply::NetworkError )>(_a, &ProviderManager::failedToLoad, 3))
            return;
    }
}

const QMetaObject *Attica::ProviderManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Attica::ProviderManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Attica15ProviderManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Attica::ProviderManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Attica::ProviderManager::providerAdded(const Attica::Provider & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Attica::ProviderManager::defaultProvidersLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Attica::ProviderManager::authenticationCredentialsMissing(const Provider & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Attica::ProviderManager::failedToLoad(const QUrl & _t1, QNetworkReply::NetworkError _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
